@@ -27,24 +27,24 @@ fobhavtoday = function()
     return(invisible(NULL))
   }
 
-  baseurl = "https://archives.nseindia.com/content/historical/DERIVATIVES/"
-  end = ".csv.zip"
-  month = format(Sys.time(), "%m")
-  month = as.integer(month)
-  month = month.abb[month]
-  month = toupper(month)
-  year = format(Sys.time(), "%Y")
-  date = format(Sys.time(), "%d")
+  x = as.character(x)
+  dy = substr(x, start = 0, stop = 2)
+  mt = substr(x, start = 3, stop = 4)
+  yr = substr(x, start = 5, stop = 8)
 
-  bhavurl = paste0(baseurl, year, "/", month, "/fo", date, month, year, "bhav", end)
-  name = paste0(date, month, year)
-  zipname = paste0("fo", date, month, year, "bhav", ".csv")
+  # NSE Bhavcopy
+  nseurl = paste0("https://nsearchives.nseindia.com/content/fo/BhavCopy_NSE_FO_0_0_0_", yr, mt, dy, "_F_0000.csv.zip")
+  #url <- "https://nsearchives.nseindia.com/content/fo/BhavCopy_NSE_FO_0_0_0_20240809_F_0000.csv.zip"
+  UA <- paste('Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:98.0)',
+              'Gecko/20100101 Firefox/98.0')
+  res <- GET(nseurl, add_headers(`User-Agent` = UA, Connection = 'keep-alive'))
 
-  temp <- tempfile()
-  download.file(bhavurl, temp)
-  file <-  read.csv(unz(temp, filename = zipname))
-  unlink(temp)
-  return(file)
+  temp_file <- tempfile() # create temporary file
+  writeBin(content(res), temp_file) # unzip CSV results to temporary file
+  df <- read_csv(temp_file) # read in temporary csv file to dataframe
+  file.remove(temp_file)
+
+  return(df)
 }
 
 
